@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use 5.010000;
 
-our $VERSION = '1.114';
+our $VERSION = '1.115';
 use Exporter 'import';
 our @EXPORT_OK = qw( choose );
 
@@ -68,7 +68,6 @@ sub __set_defaults {
     $self->{layout}           //= 1;
     #$self->{lf}              //= undef;
     #$self->{ll}              //= undef;
-    #$self->{limit}           //= undef;
     #$self->{max_height}      //= undef;
     #$self->{max_width}       //= undef;
     $self->{mouse}            //= 0;
@@ -96,7 +95,6 @@ sub __validate_options {
         layout          => '[ 0 1 2 3 ]',
         lf              => 'ARRAY',
         ll              => '[ 1-9 ][ 0-9 ]*',
-        limit           => '[ 1-9 ][ 0-9 ]*',
         max_height      => '[ 1-9 ][ 0-9 ]*',
         max_width       => '[ 1-9 ][ 0-9 ]*',
         mouse           => '[ 0 1 2 3 4 ]',
@@ -154,7 +152,8 @@ sub __reset_term {
     my ( $self, $from_choose ) = @_;
     if ( $from_choose ) {
         print CR;
-        $self->{plugin}->__up( $self->{i_row} + $self->{nr_prompt_lines} );
+        my $up = $self->{i_row} + $self->{nr_prompt_lines};
+        $self->{plugin}->__up( $up ) if $up;
         $self->{plugin}->__clear_to_end_of_screen();  ###
     }
     if ( defined $self->{plugin} ) {
@@ -209,9 +208,6 @@ sub choose {
     local $| = 1;
     $self->{wantarray} = wantarray;
     $self->__set_defaults();
-    if ( $self->{limit} && @$orig_list_ref > $self->{limit} ) {
-        $self->{list_to_long} = 1;
-    }
     $self->{orig_list} = $orig_list_ref;
     $self->__copy_orig_list();
     $self->__length_longest();
@@ -234,7 +230,8 @@ sub choose {
         if ( $new_width != $self->{term_width} || $new_height != $self->{term_height} ) {
             $self->{list} = $self->__copy_orig_list();
             print CR;
-            $self->{plugin}->__up( $self->{i_row} + $self->{nr_prompt_lines} );
+            my $up = $self->{i_row} + $self->{nr_prompt_lines};
+            $self->{plugin}->__up( $up ) if $up;
             $self->{plugin}->__clear_to_end_of_screen();
             $self->__write_first_screen();
             next;
@@ -599,58 +596,29 @@ sub __beep {
 sub __copy_orig_list {
     my ( $self ) = @_;
     if ( $self->{ll} ) {
-        if ( $self->{list_to_long} ) {
-            $self->{list} = [ map {
-                my $copy = $_;
-                if ( ! $copy ) {
-                    $copy = $self->{undef} if ! defined $copy;
-                    $copy = $self->{empty} if $copy eq '';
-                }
-                $copy;
-            } @{$self->{orig_list}}[ 0 .. $self->{limit} - 1 ] ];
-        }
-        else {
-            $self->{list} = [ map {
-                my $copy = $_;
-                if ( ! $copy ) {
-                    $copy = $self->{undef} if ! defined $copy;
-                    $copy = $self->{empty} if $copy eq '';
-                }
-                $copy;
-            } @{$self->{orig_list}} ];
-        }
+        $self->{list} = [ map {
+            my $copy = $_;
+            if ( ! $copy ) {
+                $copy = $self->{undef} if ! defined $copy;
+                $copy = $self->{empty} if $copy eq '';
+            }
+            $copy;
+        } @{$self->{orig_list}} ];
     }
     else {
-        if ( $self->{list_to_long} ) {
-            $self->{list} = [ map {
-                my $copy = $_;
-                if ( ! $copy ) {
-                    $copy = $self->{undef} if ! defined $copy;
-                    $copy = $self->{empty} if $copy eq '';
-                }
-                if ( ref $copy ) {
-                    $copy = sprintf "%s(0x%x)", ref $copy, $copy;
-                }
-                $copy =~ s/\p{Space}/ /g;  # replace, but don't squash sequences of spaces
-                $copy =~ s/\p{C}//g;
-                $copy;
-            } @{$self->{orig_list}}[ 0 .. $self->{limit} - 1 ] ];
-        }
-        else {
-            $self->{list} = [ map {
-                my $copy = $_;
-                if ( ! $copy ) {
-                    $copy = $self->{undef} if ! defined $copy;
-                    $copy = $self->{empty} if $copy eq '';
-                }
-                if ( ref $copy ) {
-                    $copy = sprintf "%s(0x%x)", ref $copy, $copy;
-                }
-                $copy =~ s/\p{Space}/ /g;
-                $copy =~ s/\p{C}//g;
-                $copy;
-            } @{$self->{orig_list}} ];
-        }
+        $self->{list} = [ map {
+            my $copy = $_;
+            if ( ! $copy ) {
+                $copy = $self->{undef} if ! defined $copy;
+                $copy = $self->{empty} if $copy eq '';
+            }
+            if ( ref $copy ) {
+                $copy = sprintf "%s(0x%x)", ref $copy, $copy;
+            }
+            $copy =~ s/\p{Space}/ /g;  # replace, but don't squash sequences of spaces
+            $copy =~ s/\p{C}//g;
+            $copy;
+        } @{$self->{orig_list}} ];
     }
 }
 
@@ -919,17 +887,14 @@ sub __goto {
         $self->{i_col} = 0;
     }
     elsif ( $newrow < $self->{i_row} ) {
-        #print UP x ( $self->{i_row} - $newrow );
         $self->{plugin}->__up( $self->{i_row} - $newrow );
         $self->{i_row} -= ( $self->{i_row} - $newrow );
     }
     if ( $newcol > $self->{i_col} ) {
-        #print RIGHT x ( $newcol - $self->{i_col} );
         $self->{plugin}->__right( $newcol - $self->{i_col} );
         $self->{i_col} += ( $newcol - $self->{i_col} );
     }
     elsif ( $newcol < $self->{i_col} ) {
-        #print LEFT x ( $self->{i_col} - $newcol );
         $self->{plugin}->__left( $self->{i_col} - $newcol );
         $self->{i_col} -= ( $self->{i_col} - $newcol );
     }
@@ -1114,7 +1079,7 @@ Term::Choose - Choose items from a list interactively.
 
 =head1 VERSION
 
-Version 1.114
+Version 1.115
 
 =cut
 
@@ -1154,10 +1119,6 @@ Object-oriented interface:
     my $stopp = Term::Choose->new( { prompt => '' } );
     $stopp->choose( [ 'Press ENTER to continue' ] );               # no choice
 
-=head1 ANNOUNCEMENT
-
-The option I<limit> will be removed with the next release.
-
 =head1 DESCRIPTION
 
 Choose interactively from a list of items.
@@ -1503,17 +1464,6 @@ See C<INITIAL_TAB> and C<SUBSEQUENT_TAB> in L<Text::LineFold>.
 
 (default: undefined)
 
-=head2 limit - Will be removed with the next release.
-
-This option will be removed with the next release.
-
-Sets the maximal allowed length of the array. (default: undefined)
-
-If the array referred by the first argument has more than I<limit> elements choose uses only the first I<limit> array
-elements.
-
-Allowed values: 1 or greater
-
 =head2 ll
 
 If all elements have the same length and this length is known before calling C<choose> the length can be passed with
